@@ -7,7 +7,7 @@
 
 #include <probes/lttng-tracepoint-event.h>
 #include <linux/types.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
 LTTNG_TRACEPOINT_EVENT_CLASS(kmem_alloc,
 
@@ -87,34 +87,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(kmem_alloc_node, kmem_cache_alloc_node,
 	TP_ARGS(call_site, ptr, bytes_req, bytes_alloc, gfp_flags, node)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,12,0))
-LTTNG_TRACEPOINT_EVENT_MAP(kfree,
-
-	kmem_kfree,
-
-	TP_PROTO(unsigned long call_site, const void *ptr),
-
-	TP_ARGS(call_site, ptr),
-
-	TP_FIELDS(
-		ctf_integer_hex(unsigned long, call_site, call_site)
-		ctf_integer_hex(const void *, ptr, ptr)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT(kmem_cache_free,
-
-	TP_PROTO(unsigned long call_site, const void *ptr, const char *name),
-
-	TP_ARGS(call_site, ptr, name),
-
-	TP_FIELDS(
-		ctf_integer_hex(unsigned long, call_site, call_site)
-		ctf_integer_hex(const void *, ptr, ptr)
-		ctf_string(name, name)
-	)
-)
-#else
 LTTNG_TRACEPOINT_EVENT_CLASS(kmem_free,
 
 	TP_PROTO(unsigned long call_site, const void *ptr),
@@ -142,10 +114,8 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(kmem_free, kmem_cache_free,
 
 	TP_ARGS(call_site, ptr)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,32))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free, kmem_mm_page_free,
 #else
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free_direct, kmem_mm_page_free_direct,
@@ -162,7 +132,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free_direct, kmem_mm_page_free_direct,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,15,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,15,0))
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free_batched, kmem_mm_page_free_batched,
 
 	TP_PROTO(struct page *page),
@@ -174,7 +144,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free_batched, kmem_mm_page_free_batched,
 		ctf_integer(unsigned long, pfn, page_to_pfn(page))
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_free_batched, kmem_mm_page_free_batched,
 
 	TP_PROTO(struct page *page, int cold),
@@ -247,16 +217,12 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(kmem_mm_page, mm_page_pcpu_drain,
 
 	kmem_mm_page_pcpu_drain,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 	TP_PROTO(struct page *page, unsigned int order, int migratetype),
-#else
-	TP_PROTO(struct page *page, int order, int migratetype),
-#endif
 
 	TP_ARGS(page, order, migratetype)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,2)	\
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,2)	\
 	|| LTTNG_KERNEL_RANGE(3,14,36, 3,15,0)		\
 	|| LTTNG_KERNEL_RANGE(3,16,35, 3,17,0)		\
 	|| LTTNG_KERNEL_RANGE(3,18,10, 3,19,0)		\
@@ -288,7 +254,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,30))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,30))
 
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 
@@ -313,7 +279,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 
@@ -340,7 +306,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 	)
 )
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
 
 LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 
@@ -364,9 +330,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(mm_page_alloc_extfrag,
 	)
 )
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
-
-#endif
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
 
 #endif /* LTTNG_TRACE_KMEM_H */
 
