@@ -9,14 +9,14 @@
 #include <scsi/scsi_cmnd.h>
 #include <scsi/scsi_host.h>
 #include <linux/trace_seq.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
 #ifndef _TRACE_SCSI_DEF
 #define _TRACE_SCSI_DEF
 
 #define scsi_opcode_name(opcode)	{ opcode, #opcode }
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,7,0) \
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,7,0) \
 	|| LTTNG_SLE_KERNEL_RANGE(4,4,9,36,0,0, 4,5,0,0,0,0))
 
 #define show_opcode_name(val)					\
@@ -112,7 +112,7 @@
 		scsi_opcode_name(ATA_16),			\
 		scsi_opcode_name(ATA_12))
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0) \
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0) \
 	|| LTTNG_RHEL_KERNEL_RANGE(3,10,0,327,0,0, 3,11,0,0,0,0))
 
 #define show_opcode_name(val)					\
@@ -210,7 +210,7 @@
 		scsi_opcode_name(ATA_16),			\
 		scsi_opcode_name(ATA_12))
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0)) */
 
 #define show_opcode_name(val)					\
 	__print_symbolic(val,					\
@@ -307,7 +307,7 @@
 		scsi_opcode_name(ATA_16),			\
 		scsi_opcode_name(ATA_12))
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0)) */
 
 #define scsi_hostbyte_name(result)	{ result, #result }
 #define show_hostbyte_name(val)					\
@@ -388,7 +388,6 @@
 		scsi_statusbyte_name(SAM_STAT_ACA_ACTIVE),	\
 		scsi_statusbyte_name(SAM_STAT_TASK_ABORTED))
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 #define scsi_prot_op_name(result)	{ result, #result }
 #define show_prot_op_name(val)					\
 	__print_symbolic(val,					\
@@ -399,7 +398,6 @@
 		scsi_prot_op_name(SCSI_PROT_WRITE_INSERT),	\
 		scsi_prot_op_name(SCSI_PROT_READ_PASS),		\
 		scsi_prot_op_name(SCSI_PROT_WRITE_PASS))
-#endif
 
 const char *scsi_trace_parse_cdb(struct trace_seq*, unsigned char*, int);
 #define __parse_cdb(cdb, len) scsi_trace_parse_cdb(p, cdb, len)
@@ -420,9 +418,7 @@ LTTNG_TRACEPOINT_EVENT(scsi_dispatch_cmd_start,
 		ctf_integer(unsigned int, cmd_len, cmd->cmd_len)
 		ctf_integer(unsigned int, data_sglen, scsi_sg_count(cmd))
 		ctf_integer(unsigned int, prot_sglen, scsi_prot_sg_count(cmd))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(unsigned char, prot_op, scsi_get_prot_op(cmd))
-#endif
 		ctf_sequence_hex(unsigned char, cmnd, cmd->cmnd, u32, cmd->cmd_len)
 	)
 )
@@ -443,9 +439,7 @@ LTTNG_TRACEPOINT_EVENT(scsi_dispatch_cmd_error,
 		ctf_integer(unsigned int, cmd_len, cmd->cmd_len)
 		ctf_integer(unsigned int, data_sglen, scsi_sg_count(cmd))
 		ctf_integer(unsigned int, prot_sglen, scsi_prot_sg_count(cmd))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(unsigned char, prot_op, scsi_get_prot_op(cmd))
-#endif
 		ctf_sequence_hex(unsigned char, cmnd, cmd->cmnd, u32, cmd->cmd_len)
 	)
 )
@@ -466,9 +460,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(scsi_cmd_done_timeout_template,
 		ctf_integer(unsigned int, cmd_len, cmd->cmd_len)
 		ctf_integer(unsigned int, data_sglen, scsi_sg_count(cmd))
 		ctf_integer(unsigned int, prot_sglen, scsi_prot_sg_count(cmd))
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,39))
 		ctf_integer(unsigned char, prot_op, scsi_get_prot_op(cmd))
-#endif
 		ctf_sequence_hex(unsigned char, cmnd, cmd->cmnd, u32, cmd->cmd_len)
 	)
 )
