@@ -7,9 +7,7 @@
 
 #include <probes/lttng-tracepoint-event.h>
 #include <linux/workqueue.h>
-#include <lttng-kernel-version.h>
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,36))
+#include <linux/version.h>
 
 #ifndef _TRACE_WORKQUEUE_DEF_
 #define _TRACE_WORKQUEUE_DEF_
@@ -30,7 +28,6 @@ LTTNG_TRACEPOINT_EVENT_CLASS(workqueue_work,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 /**
  * workqueue_queue_work - called when a work gets queued
  * @req_cpu:	the requested cpu
@@ -43,7 +40,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(workqueue_work,
  */
 LTTNG_TRACEPOINT_EVENT(workqueue_queue_work,
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
 	TP_PROTO(unsigned int req_cpu, struct pool_workqueue *pwq,
 		 struct work_struct *work),
 
@@ -76,7 +73,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(workqueue_work, workqueue_activate_work,
 
 	TP_ARGS(work)
 )
-#endif
 
 /**
  * workqueue_execute_start - called immediately before the workqueue callback
@@ -96,7 +92,7 @@ LTTNG_TRACEPOINT_EVENT(workqueue_execute_start,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
 /**
  * workqueue_execute_end - called immediately after the workqueue callback
  * @work:	pointer to struct work_struct
@@ -130,63 +126,6 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(workqueue_work, workqueue_execute_end,
 )
 #endif
 
-#else
-
-LTTNG_TRACEPOINT_EVENT_CLASS(workqueue,
-
-	TP_PROTO(struct task_struct *wq_thread, struct work_struct *work),
-
-	TP_ARGS(wq_thread, work),
-
-	TP_FIELDS(
-		ctf_array(char, thread_comm, wq_thread->comm, TASK_COMM_LEN)
-		ctf_integer(pid_t, thread_pid, wq_thread->pid)
-		ctf_integer_hex(work_func_t, func, work->func)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE(workqueue, workqueue_insertion,
-
-	TP_PROTO(struct task_struct *wq_thread, struct work_struct *work),
-
-	TP_ARGS(wq_thread, work)
-)
-
-LTTNG_TRACEPOINT_EVENT_INSTANCE(workqueue, workqueue_execution,
-
-	TP_PROTO(struct task_struct *wq_thread, struct work_struct *work),
-
-	TP_ARGS(wq_thread, work)
-)
-
-/* Trace the creation of one workqueue thread on a cpu */
-LTTNG_TRACEPOINT_EVENT(workqueue_creation,
-
-	TP_PROTO(struct task_struct *wq_thread, int cpu),
-
-	TP_ARGS(wq_thread, cpu),
-
-	TP_FIELDS(
-		ctf_array(char, thread_comm, wq_thread->comm, TASK_COMM_LEN)
-		ctf_integer(pid_t, thread_pid, wq_thread->pid)
-		ctf_integer(int, cpu, cpu)
-	)
-)
-
-LTTNG_TRACEPOINT_EVENT(workqueue_destruction,
-
-	TP_PROTO(struct task_struct *wq_thread),
-
-	TP_ARGS(wq_thread),
-
-	TP_FIELDS(
-		ctf_array(char, thread_comm, wq_thread->comm, TASK_COMM_LEN)
-		ctf_integer(pid_t, thread_pid, wq_thread->pid)
-	)
-)
-
-#endif
-
 #endif /*  LTTNG_TRACE_WORKQUEUE_H */
 
 /* This part must be outside protection */
