@@ -9,30 +9,11 @@
 #include <linux/tracepoint.h>
 #include <linux/backing-dev.h>
 #include <linux/writeback.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 
 #ifndef _TRACE_WRITEBACK_DEF_
 #define _TRACE_WRITEBACK_DEF_
 
-/*
- * Use the GPL-exported bdi_dev_name introduced in kernel 5.7. Do not use
- * static inline bdi_dev_name in prior kernels because it uses the bdi_unknown_name
- * symbol which is not exported to GPL modules.
- */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,7,0))
-static inline const char *lttng_bdi_dev_name(struct backing_dev_info *bdi)
-{
-	return bdi_dev_name(bdi);
-}
-#else
-static inline const char *lttng_bdi_dev_name(struct backing_dev_info *bdi)
-{
-	if (!bdi || !bdi->dev)
-		return "(unknown)";
-	return dev_name(bdi->dev);
-}
-#endif
-
 /*
  * Vanilla kernels before 4.0 do not implement inode_to_bdi
  * RHEL kernels before 3.10.0-327.10.1 do not implement inode_to_bdi
@@ -41,7 +22,7 @@ static inline const char *lttng_bdi_dev_name(struct backing_dev_info *bdi)
  *  commit a212b105b07d75b48b1a166378282e8a77fbf53d which inlines
  *  inode_to_bdi but not sb_is_blkdev_sb making it unusable by modules.
  */
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(4,0,0))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,0,0))
 static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 {
 	struct super_block *sb;
@@ -61,36 +42,11 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 {
 	return inode_to_bdi(inode);
 }
-#endif /* #if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(4,0,0)) */
+#endif /* #if (LINUX_VERSION_CODE < KERNEL_VERSION(4,0,0)) */
 
 #endif
 
-/*
- * Keep this macro around to track changes in the valid values for `state`.
- * Eventually, we will have a enum to describe that field. If the macro is
- * changed by an upstream kernel, the fact that we have a redefinition here
- * will generate a compiler warning.
- */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0) || \
-	LTTNG_KERNEL_RANGE(4,14,218, 4,15,0) ||			\
-	LTTNG_KERNEL_RANGE(4,19,172, 4,20,0) ||			\
-	LTTNG_KERNEL_RANGE(5,4,94, 5,5,0) ||			\
-	LTTNG_UBUNTU_KERNEL_RANGE(4,15,18,141, 4,16,0,0) ||	\
-	LTTNG_RHEL_KERNEL_RANGE(4,18,0,240,0,0, 4,19,0,0,0,0))
-#define show_inode_state(state)					\
-	__print_flags(state, "|",				\
-		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
-		{I_DIRTY_DATASYNC,	"I_DIRTY_DATASYNC"},	\
-		{I_DIRTY_PAGES,		"I_DIRTY_PAGES"},	\
-		{I_NEW,			"I_NEW"},		\
-		{I_WILL_FREE,		"I_WILL_FREE"},		\
-		{I_FREEING,		"I_FREEING"},		\
-		{I_CLEAR,		"I_CLEAR"},		\
-		{I_SYNC,		"I_SYNC"},		\
-		{I_DIRTY_TIME,		"I_DIRTY_TIME"},	\
-		{I_REFERENCED,		"I_REFERENCED"}		\
-	)
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
 #define show_inode_state(state)					\
 	__print_flags(state, "|",				\
 		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
@@ -105,7 +61,7 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 		{I_DIRTY_TIME_EXPIRED,	"I_DIRTY_TIME_EXPIRED"}, \
 		{I_REFERENCED,		"I_REFERENCED"}		\
 	)
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
 #define show_inode_state(state)					\
 	__print_flags(state, "|",				\
 		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
@@ -118,15 +74,16 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 		{I_SYNC,		"I_SYNC"},		\
 		{I_REFERENCED,		"I_REFERENCED"}		\
 	)
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
 
 LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 	TP_PROTO(struct page *page, struct address_space *mapping),
 	TP_ARGS(page, mapping),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(mapping ? lttng_inode_to_bdi(mapping->host) : NULL))
+		ctf_array_text(char, name,
+			mapping ? dev_name(lttng_inode_to_bdi(mapping->host)->dev) : "(unknown)", 32)
 		ctf_integer(unsigned long, ino, mapping ? mapping->host->i_ino : 0)
 		ctf_integer(pgoff_t, index, page->index)
 	)
@@ -137,7 +94,9 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_dirty_inode_template,
 	TP_ARGS(inode, flags),
 	TP_FIELDS(
 		/* may be called for files on pseudo FSes w/ unregistered bdi */
-		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
+		ctf_array_text(char, name,
+			lttng_inode_to_bdi(inode)->dev ?
+				dev_name(lttng_inode_to_bdi(inode)->dev) : "(unknown)", 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, flags, flags)
@@ -155,7 +114,8 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_write_inode_template,
 	TP_PROTO(struct inode *inode, struct writeback_control *wbc),
 	TP_ARGS(inode, wbc),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
+		ctf_array_text(char, name,
+			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
 	)
@@ -168,13 +128,14 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_write_inode_template, name, \
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode)
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
 
 LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 	TP_PROTO(struct page *page, struct address_space *mapping),
 	TP_ARGS(page, mapping),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(mapping ? mapping->backing_dev_info : NULL))
+		ctf_array_text(char, name,
+			mapping ? dev_name(mapping->backing_dev_info->dev) : "(unknown)", 32)
 		ctf_integer(unsigned long, ino, mapping ? mapping->host->i_ino : 0)
 		ctf_integer(pgoff_t, index, page->index)
 	)
@@ -185,7 +146,10 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_dirty_inode_template,
 	TP_ARGS(inode, flags),
 	TP_FIELDS(
 		/* may be called for files on pseudo FSes w/ unregistered bdi */
-		ctf_string(name, lttng_bdi_dev_name(inode->i_mapping->backing_dev_info))
+		ctf_array_text(char, name,
+			inode->i_mapping->backing_dev_info->dev ?
+				dev_name(inode->i_mapping->backing_dev_info->dev)
+				: "(unknown)", 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, flags, flags)
 	)
@@ -201,7 +165,8 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_write_inode_template,
 	TP_PROTO(struct inode *inode, struct writeback_control *wbc),
 	TP_ARGS(inode, wbc),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(inode->i_mapping->backing_dev_info))
+		ctf_array_text(char, name,
+			dev_name(inode->i_mapping->backing_dev_info->dev), 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
 	)
@@ -214,50 +179,64 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_write_inode_template, name, \
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode)
 
-#endif /* (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0)) */
+#endif /* (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
 	TP_PROTO(struct bdi_writeback *wb, struct wb_writeback_work *work),
 	TP_ARGS(wb, work),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
+		ctf_array_text(char, name, wb->bdi->dev ? dev_name(wb->bdi->dev) :
+				"(unknown)", 32)
 	)
 )
 
-#else
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
 	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work),
 	TP_ARGS(bdi, work),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, name, bdi->dev ? dev_name(bdi->dev) :
+				"(unknown)", 32)
 	)
 )
 
-#endif /* #else if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
+LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
+	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work),
+	TP_ARGS(bdi, work),
+	TP_FIELDS(
+		ctf_array_text(char, name,
+			dev_name(bdi->dev ? bdi->dev :
+				default_backing_dev_info.dev), 32)
+	)
+)
+
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
+
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
 
 #define LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(name) \
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_work_class, name, \
 	TP_PROTO(struct bdi_writeback *wb, struct wb_writeback_work *work), \
 	TP_ARGS(wb, work))
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 #define LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(name) \
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_work_class, name, \
 	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work), \
 	TP_ARGS(bdi, work))
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_nothread)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_queue)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_exec)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_written)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_wait)
@@ -271,13 +250,14 @@ LTTNG_TRACEPOINT_EVENT(writeback_pages_written,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_class,
 	TP_PROTO(struct bdi_writeback *wb),
 	TP_ARGS(wb),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
+		ctf_array_text(char, name,
+			dev_name(wb->bdi->dev), 32)
 	)
 )
 
@@ -296,17 +276,19 @@ LTTNG_TRACEPOINT_EVENT(writeback_bdi_register,
 	TP_PROTO(struct backing_dev_info *bdi),
 	TP_ARGS(bdi),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, name,
+			dev_name(bdi->dev), 32)
 	)
 )
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_class,
 	TP_PROTO(struct backing_dev_info *bdi),
 	TP_ARGS(bdi),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, name,
+			dev_name(bdi->dev), 32)
 	)
 )
 
@@ -323,12 +305,10 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(writeback_class, name, map, \
 
 DEFINE_WRITEBACK_EVENT(writeback_bdi_register)
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 DEFINE_WRITEBACK_EVENT(writeback_nowork)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,38))
 DEFINE_WRITEBACK_EVENT(writeback_wake_background)
-#endif
 DEFINE_WRITEBACK_EVENT(writeback_wake_thread)
 DEFINE_WRITEBACK_EVENT(writeback_wake_forker_thread)
 DEFINE_WRITEBACK_EVENT(writeback_bdi_unregister)
@@ -347,7 +327,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_written,
 	TP_ARGS(bdi, written),
 
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, name, dev_name(bdi->dev), 32)
 		ctf_integer(int, written, written)
 	)
 )
@@ -357,7 +337,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
 	TP_ARGS(wbc, bdi),
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, name, dev_name(bdi->dev), 32)
 		ctf_integer(long, nr_to_write, wbc->nr_to_write)
 		ctf_integer(long, pages_skipped, wbc->pages_skipped)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
@@ -365,7 +345,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 		ctf_integer(int, for_background, wbc->for_background)
 		ctf_integer(int, for_reclaim, wbc->for_reclaim)
 		ctf_integer(int, range_cyclic, wbc->range_cyclic)
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0))
 		ctf_integer(int, more_io, wbc->more_io)
 		ctf_integer(unsigned long, older_than_this,
 			wbc->older_than_this ? *wbc->older_than_this : 0)
@@ -380,7 +360,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(writeback_wbc_class, name, map, \
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi), \
 	TP_ARGS(wbc, bdi))
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_start, writeback_wbc_writeback_start)
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_written, writeback_wbc_writeback_written)
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_wait, writeback_wbc_writeback_wait)
@@ -390,58 +370,36 @@ LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_balance_dirty_wait, writeback_wbc_balanc
 #endif
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writepage, writeback_wbc_writepage)
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0) || \
-	LTTNG_KERNEL_RANGE(5,8,6, 5,9,0) || \
-	LTTNG_KERNEL_RANGE(5,4,62, 5,5,0) || \
-	LTTNG_KERNEL_RANGE(4,19,143, 4,20,0) || \
-	LTTNG_KERNEL_RANGE(4,14,196, 4,15,0) || \
-	LTTNG_KERNEL_RANGE(4,9,235, 4,10,0) || \
-	LTTNG_KERNEL_RANGE(4,4,235, 4,5,0) || \
-	LTTNG_UBUNTU_KERNEL_RANGE(4,15,18,119, 4,16,0,0) || \
-	LTTNG_RHEL_KERNEL_RANGE(4,18,0,240,0,0, 4,19,0,0,0,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
 	TP_PROTO(struct bdi_writeback *wb,
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 		 struct wb_writeback_work *work,
-		 unsigned long dirtied_before,
-		 int moved),
-	TP_ARGS(wb, work, dirtied_before, moved),
-	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
-		ctf_integer(unsigned long, older, dirtied_before)
-		ctf_integer(int, moved, moved)
-	)
-)
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
-LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
-	TP_PROTO(struct bdi_writeback *wb,
-		 struct wb_writeback_work *work,
-		 int moved),
-	TP_ARGS(wb, work, moved),
-	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
-		ctf_integer(int, moved, moved)
-	)
-)
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
-LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
-	TP_PROTO(struct bdi_writeback *wb,
+#else
 		 unsigned long *older_than_this,
+#endif
 		 int moved),
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
+	TP_ARGS(wb, work, moved),
+#else
 	TP_ARGS(wb, older_than_this, moved),
+#endif
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
+		ctf_array_text(char, name, dev_name(wb->bdi->dev), 32)
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
+#else
 		ctf_integer(unsigned long, older,
 			older_than_this ? *older_than_this : 0)
 		ctf_integer(long, age,
 			older_than_this ?
 				(jiffies - *older_than_this) * 1000 / HZ
 				: -1)
+#endif
 		ctf_integer(int, moved, moved)
 	)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,8,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,8,0))
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -464,7 +422,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 		ctf_integer(unsigned long, dirty_limit, global_dirty_limit)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,14,0))
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -488,7 +446,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 		ctf_integer(unsigned long, dirty_limit, global_dirty_limit)
 	)
 )
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
+#else
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -513,12 +471,13 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 	)
 )
 #endif
+#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
 
 #define KBps(x)			((x) << (PAGE_SHIFT - 10))
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -531,7 +490,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(wb, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_string(bdi, lttng_bdi_dev_name(wb->bdi))
+		ctf_array_text(char, bdi, dev_name(wb->bdi->dev), 32)
 		ctf_integer(unsigned long, write_bw, KBps(wb->bdi->wb.write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(wb->bdi->wb.avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -542,7 +501,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0))
+#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -555,7 +514,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(bdi, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_string(bdi, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
 		ctf_integer(unsigned long, write_bw, KBps(bdi->wb.write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(bdi->wb.avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -566,7 +525,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0)) */
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -579,7 +538,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(bdi, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_string(bdi, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
 		ctf_integer(unsigned long, write_bw, KBps(bdi->write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(bdi->avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -590,9 +549,9 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
@@ -617,7 +576,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	),
 
 	TP_FIELDS(
-		ctf_string(bdi, lttng_bdi_dev_name(wb->bdi))
+		ctf_array_text(char, bdi, dev_name(wb->bdi->dev), 32)
 		ctf_integer(unsigned long, limit, global_dirty_limit)
 		ctf_integer(unsigned long, setpoint,
 			(global_dirty_limit + (thresh + bg_thresh) / 2) / 2)
@@ -644,7 +603,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	)
 )
 
-#else /* #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#else /* #if LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
@@ -659,7 +618,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 		 unsigned long dirty_ratelimit,
 		 unsigned long task_ratelimit,
 		 unsigned long dirtied,
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 		 unsigned long period,
 #endif
 		 long pause,
@@ -667,7 +626,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
 	TP_ARGS(bdi, thresh, bg_thresh, dirty, bdi_thresh, bdi_dirty,
 		dirty_ratelimit, task_ratelimit,
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 		dirtied, period, pause, start_time
 #else
 		dirtied, pause, start_time
@@ -675,7 +634,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	),
 
 	TP_FIELDS(
-		ctf_string(bdi, lttng_bdi_dev_name(bdi))
+		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
 		ctf_integer(unsigned long, limit, global_dirty_limit)
 		ctf_integer(unsigned long, setpoint,
 			(global_dirty_limit + (thresh + bg_thresh) / 2) / 2)
@@ -694,7 +653,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 		ctf_integer(unsigned long, paused,
 			(jiffies - start_time) * 1000 / HZ)
 		ctf_integer(long, pause, pause * 1000 / HZ)
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
 		ctf_integer(unsigned long, period,
 			period * 1000 / HZ)
 		ctf_integer(long, think,
@@ -703,18 +662,19 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 #endif
 	)
 )
-#endif /* #else #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
 
-#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0)) */
+#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0)) */
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,5,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,5,0))
 LTTNG_TRACEPOINT_EVENT(writeback_sb_inodes_requeue,
 
 	TP_PROTO(struct inode *inode),
 	TP_ARGS(inode),
 
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
+		ctf_array_text(char, name,
+			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, dirtied_when, inode->dirtied_when)
@@ -722,7 +682,6 @@ LTTNG_TRACEPOINT_EVENT(writeback_sb_inodes_requeue,
 )
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_congest_waited_template,
 
 	TP_PROTO(unsigned int usec_timeout, unsigned int usec_delayed),
@@ -748,9 +707,8 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_congest_waited_template, writeback_wai
 
 	TP_ARGS(usec_timeout, usec_delayed)
 )
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 
 	TP_PROTO(struct inode *inode,
@@ -761,7 +719,8 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 	TP_ARGS(inode, wbc, nr_to_write),
 
 	TP_FIELDS(
-		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
+		ctf_array_text(char, name,
+			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, dirtied_when, inode->dirtied_when)
@@ -773,7 +732,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 	)
 )
 
-#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,5,0))
+#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,5,0))
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_single_inode_template, writeback_single_inode_requeue,
 	TP_PROTO(struct inode *inode,
 		struct writeback_control *wbc,
