@@ -1,30 +1,19 @@
-#ifndef _LIB_RING_BUFFER_BACKEND_TYPES_H
-#define _LIB_RING_BUFFER_BACKEND_TYPES_H
-
-/*
+/* SPDX-License-Identifier: (GPL-2.0 OR LGPL-2.1)
+ *
  * lib/ringbuffer/backend_types.h
  *
  * Ring buffer backend (types).
  *
  * Copyright (C) 2008-2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; only
- * version 2.1 of the License.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
+#ifndef _LIB_RING_BUFFER_BACKEND_TYPES_H
+#define _LIB_RING_BUFFER_BACKEND_TYPES_H
+
 #include <linux/cpumask.h>
 #include <linux/types.h>
+#include <lttng-kernel-version.h>
+#include <lttng-cpuhotplug.h>
 
 struct lib_ring_buffer_backend_page {
 	void *virt;			/* page virtual address (cached) */
@@ -97,7 +86,11 @@ struct channel_backend {
 	void *priv;			/* Client-specific information */
 	void *priv_ops;			/* Client-specific ops pointer */
 	void (*release_priv_ops)(void *priv_ops);
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,10,0))
+	struct lttng_cpuhp_node cpuhp_prepare;	/* CPU hotplug prepare */
+#else
 	struct notifier_block cpu_hp_notifier;	 /* CPU hotplug notifier */
+#endif
 	/*
 	 * We need to copy config because the module containing the
 	 * source config can vanish before the last reference to this
