@@ -9,19 +9,14 @@
  */
 
 #include <linux/module.h>
-#include <lttng-kernel-version.h>
+#include <linux/version.h>
 #include <lttng-tracer.h>
 
 /*
  * Create the tracepoint static inlines from the kernel to validate that our
  * trace event macros match the kernel we run on.
  */
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
 #include <trace/events/lock.h>
-#else
-#include <trace/events/lockdep.h>
-#endif
-
 #include <wrapper/tracepoint.h>
 
 /*
