@@ -10,14 +10,10 @@
 #ifndef _LTTNG_WRAPPER_ATOMIC_H
 #define _LTTNG_WRAPPER_ATOMIC_H
 
-#include <lttng-kernel-version.h>
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,37))
+#include <linux/version.h>
 #include <linux/atomic.h>
-#else
-#include <asm/atomic.h>
-#endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0))
+#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,16,0))
 static inline void lttng_smp_mb__before_atomic(void)
 {
 	smp_mb__before_atomic();
@@ -27,7 +23,7 @@ static inline void lttng_smp_mb__after_atomic(void)
 {
 	smp_mb__after_atomic();
 }
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0)) */
+#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,16,0)) */
 static inline void lttng_smp_mb__before_atomic(void)
 {
 	smp_mb__before_atomic_inc();
@@ -37,6 +33,6 @@ static inline void lttng_smp_mb__after_atomic(void)
 {
 	smp_mb__after_atomic_inc();
 }
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,16,0)) */
+#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,16,0)) */
 
 #endif /* _LTTNG_WRAPPER_ATOMIC_H */
