@@ -14,7 +14,7 @@
 /* boot_id depends on sysctl */
 #if defined(CONFIG_SYSCTL)
 
-#include <wrapper/fs.h>
+#include <linux/fs.h>
 #include <linux/file.h>
 #include <linux/sched.h>
 #include <linux/uaccess.h>
@@ -28,12 +28,21 @@ int wrapper_get_bootid(char *bootid)
 	struct file *file;
 	int ret;
 	ssize_t len;
+	mm_segment_t old_fs;
 
 	file = filp_open("/proc/sys/kernel/random/boot_id", O_RDONLY, 0);
 	if (IS_ERR(file))
 		return PTR_ERR(file);
 
-	len = lttng_kernel_read(file, bootid, BOOT_ID_LEN - 1, &file->f_pos);
+	old_fs = get_fs();
+	set_fs(KERNEL_DS);
+
+	if (!file->f_op || !file->f_op->read) {
+		ret = -EINVAL;
+		goto end;
+	}
+
+	len = file->f_op->read(file, bootid, BOOT_ID_LEN - 1, &file->f_pos);
 	if (len != BOOT_ID_LEN - 1) {
 		ret = -EINVAL;
 		goto end;
@@ -42,6 +51,7 @@ int wrapper_get_bootid(char *bootid)
 	bootid[BOOT_ID_LEN - 1] = '\0';
 	ret = 0;
 end:
+	set_fs(old_fs);
 	filp_close(file, current->files);
 	return ret;
 }
